@@ -36,15 +36,11 @@ class FeatureUtil(object):
     def __init__(self, config):
         self.config = config
         self.maxlen = config['maxlen']
-        self.batchsize = config['batchsize']
-        self.class_num = config['class_num']
         self.cross_feature_num = config['cross_feature_num']
         self.user_feature_num = config['user_feature_num']
         self.user_feature_size = config['user_feature_size']
-        self.output_unit = config['output_unit']
-        self.multi_class = config['multi_class']
-        self.neg_sample = config['neg_sample']
-        self.seq_num = self.config['seq_num']
+        self.output_unit = config.get('output_unit', config.get('class_num',2))
+        self.seq_num = config['seq_num']
 
     def feature_extraction(self, data, serving=False, write_to='hdf5'):
         '''
@@ -83,9 +79,10 @@ class FeatureUtil(object):
               sorted(re.split(', |,', xx), key=lambda x: x.split(':')[-1])][-self.maxlen:] if xx else [0] for xx in
              sample.split('@')[feature_id['sequence_feature']].split(';')[:self.seq_num]]
             for sample in data]
+
         sequence_time = [
             [[int(sample.split('@')[feature_id['cur_time']]) - int(x.split(':')[1]) for x in
-              sorted(re.split(', |,', xx), key=lambda x: x.split(':')[-1])][-self.maxlen:] if xx else [0] for xx in
+              sorted(re.split(', |,', xx), key=lambda x: x.split(':')[-1])][-self.maxlen:] if ':' in xx else [0]*len(re.split(', |,', xx)) for xx in
              sample.split('@')[feature_id['sequence_feature']].split(';')[:self.seq_num]]
             for sample in data]
         sequence_time_gaps = [[[0] + [abs(xx[i] - xx[i - 1]) for i in range(1, len(xx))] for xx in sample] for sample in sequence_time]
